{% extends "base.html" %}
{% load i18n towel_form_tags %}

{% block title %}{% trans "Set password" %} - {{ block.super }}{% endblock %}

{% block page-header %}
<div class="page-header">
  <h1>{% trans "Set password" %}</h1>
</div>
{% endblock %}

{% block content %}
<form action="." method="post" class="form form-horizontal">
  {% csrf_token %}
  {% form_errors form %}
  {% form_item form.new_password1 %}
  {% form_item form.new_password2 %}

  <div class="form-actions">
    <button type="submit" class="btn btn-primary">
      {% trans "Set password" %}</button>
  </div>

  <script type="text/javascript">document.getElementById("{{ form.new_password1.auto_id }}").focus();</script>
</form>
{% endblock %}
